#!/usr/bin/perl
use 5.014000;
use warnings;

use Convert::Color::RGB8;
use JSON::PP qw/decode_json/;
use Test::More;

use constant EPSILON => 1e-4; # 1e-11 is OK on amd64

open my $fh, '<', 't/snapshot-rev3.json';
my $snapshot = join '', <$fh>;
close $fh;

my %tests = %{decode_json $snapshot};
my @colors = sort keys %tests;

plan tests => 5 * @colors;

sub isf {
	my ($x, $y, $name) = @_;
	my $ok = 1;
	$ok &&= abs ($x->[$_] - $y->[$_]) < EPSILON for 0, 1, 2;
	return pass $name if $ok;
	local $" = ', ';
	fail $name;
	diag "[@$x] != [@$y]";
}

for my $color (@colors) {
	my %color = %{$tests{$color}};
	my $col = Convert::Color::RGB8->new(substr $color, 1);
	isf $col->convert_to('xyz'),   $color{xyz},   "convert $color to XYZ";
	isf $col->convert_to('luv'),   $color{luv},   "convert $color to LUV";
	isf $col->convert_to('lch'),   $color{lch},   "convert $color to LCh";
	isf $col->convert_to('husl'),  $color{husl},  "convert $color to HUSL";
	isf $col->convert_to('huslp'), $color{huslp}, "convert $color to HUSLp";
}
